#
# spec file for package python-magnumclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-magnumclient
Version:        4.7.0
Release:        1.2
Summary:        Python API and CLI for OpenStack Magnum
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-magnumclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-magnumclient/python-magnumclient-4.7.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PrettyTable >= 0.7.2
BuildRequires:  python3-cryptography >= 3.0
BuildRequires:  python3-decorator >= 3.4.0
BuildRequires:  python3-fixtures
BuildRequires:  python3-keystoneauth1 >= 3.4.0
BuildRequires:  python3-openstackclient
BuildRequires:  python3-os-client-config >= 1.28.0
BuildRequires:  python3-osc-lib >= 1.8.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-osprofiler
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-python-subunit
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
Client library for Magnum built on the Magnum API. It provides a Python API
(the magnumclient module) and a command-line tool (magnum).

%package -n python3-magnumclient
Summary:        Python API and CLI for OpenStack Magnum
Requires:       python3-PrettyTable >= 0.7.2
Requires:       python3-cryptography >= 3.0
Requires:       python3-decorator >= 3.4.0
Requires:       python3-keystoneauth1 >= 3.4.0
Requires:       python3-os-client-config >= 1.28.0
Requires:       python3-osc-lib >= 1.8.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.log >= 3.36.0
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-pbr >= 2.0.0
Requires:       python3-requests >= 2.14.2
Requires:       python3-stevedore >= 1.20.0
%if 0%{?suse_version}
Obsoletes:      python2-magnumclient < 2.17.0
%endif

%description -n python3-magnumclient
Client library for Magnum built on the Magnum API. It provides a Python API
(the magnumclient module) and a command-line tool (magnum).

This package contains the Python 3.x module.

%package -n python-magnumclient-doc
Summary:        Documentation for OpenStack Magnum API client libary
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-magnumclient-doc
Client library for Magnum built on the Magnum API. It provides a Python API
(the magnumclient module) and a command-line tool (magnum).
This package contains the documentation.

%prep
%autosetup -p1 -n python-magnumclient-4.7.0
%py_req_cleanup

%build
%{py3_build}

# Build HTML docs and man page
PBR_VERSION=4.7.0 %sphinx_build -b html doc/source doc/build/html
PBR_VERSION=4.7.0 %sphinx_build -b man doc/source doc/build/man
rm -r doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}
# man page
install -p -D -m 644 doc/build/man/python-magnumclient.1 %{buildroot}%{_mandir}/man1/magnum.1
# Install bash completion
install -p -D -m 644 tools/magnum.bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/magnum.bash_completion

%check
%{openstack_stestr_run}

%files -n python3-magnumclient
%license LICENSE
%{python3_sitelib}/magnumclient
%{python3_sitelib}/*.egg-info
%{_bindir}/magnum
%{_mandir}/man1/magnum.1.*
%{_sysconfdir}/bash_completion.d/magnum.bash_completion

%files -n python-magnumclient-doc
%doc README.rst doc/build/html
%license LICENSE

%changelog
* Tue Sep  3 2024 cloud-devel@suse.de
- update to version 4.7.0
  - Update Python runtime for 2024.2
  - Refactor TLS cert fetching for config
  - Update VerifiedHTTPSConnection for Python >= 3.12
  - Remove extraneous quote in non-TLS kubeconfig
  - Add insecure_registry to osc part of the client
* Tue Jun  4 2024 cloud-devel@suse.de
- update to version 4.5.0
  - Update master for stable/2024.1
  - Replace deprecated inspector.getargspec
  - Display project_id for cluster template
  - Always use io module
  - reno: Update master for unmaintained/zed
* Thu May  2 2024 cloud-devel@suse.de
- removed 0001-Fix-test_help_on_subcommand-on-Python-3.10.patch
- update to version 4.4.0
  - Update python testing as per zed cycle testing runtime
  - Use TOX_CONSTRAINTS_FILE
  - Fix multi-line strings spaces
  - Clean up tox.ini
  - Remove pypy and bump py37 to py38
  - Update master for stable/zed
  - Update client.authentication.k8s.io api version for kubeconfig
  - Update master for stable/2023.1
  - Fix test_help_on_subcommand on Python 3.10
  - Add python 3.10 to setup.cfg metadata
  - Switch to 2023.1 Python3 unit tests and generic template name
  - Update master for stable/yoga
  - setup.cfg: rename deprecated dash-separated options
  - Drop bay and baymodel
  - Imported Translations from Zanata
  - Support tox4
  - Remove translation sections from setup.cfg
  - Update master for stable/2023.2
  - Update python classifier in setup.cfg
  - Allow directly output cluster config
  - Drop lower-constraints.txt and its testing
  - remove unicode from code
  - Bugfix: master_lb_enabled flag now works as intended.
  - reno: Update master for unmaintained/yoga
* Sun Jun 19 2022 cloud-devel@suse.de
- added 0001-Fix-test_help_on_subcommand-on-Python-3.10.patch
* Sun Jun 19 2022 cloud-devel@suse.de
- update to version 3.6.0
  - Update master for stable/victoria
  - Update master for stable/wallaby
  - Add Python3 wallaby unit tests
  - Update master for stable/xena
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 3.5.0
  - Fix failing to parse json error msg
  - Fix master_lb_enabled for cluster creation
* Sun May  2 2021 cloud-devel@suse.de
- update to version 3.4.0
  - Show docker_volume_size in `cluster show`
  - Uncap PrettyTable
  - Add CT tags argument and field to client
  - Nodegroup min_node_count should default to 0
  - Drop lower constraints testing
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 3.2.1
  - Switch to newer openstackdocstheme and reno versions
  - Update to hacking 3.0
  - Rename variables to address pep8 error
  - Refactor the getid method base.py
  - Use unittest.mock instead of mock
  - Support master_lb_enabled when creating cluster
  - Use unittest.mock instead of third party mock
  - replace launchpad urls with storyboard urls
  - Add Python3 victoria unit tests
  - Support updating cluster health status
  - Cleanup py27 support
  - Update master for stable/ussuri
  - Add py38 package metadata
  - Migrate testing to Ubuntu Focal
  - Fix raw_request of SessionClient
  - Remove six
  - Fix hacking min version to 3.0.1
  - Stop to use the __future__ module.
  - Print response after issuing CA rotate request
  - Labels override
  - Use overlay2 driver by default
  - Check response type in _extract_error_json
  - Show cluster fixed_network, fixed_subnet, floating_ip_enabled
* Mon Aug 10 2020 cloud-devel@suse.de
- update to version 3.0.1
  - Rename variables to address pep8 error
  - Update TOX/UPPER_CONSTRAINTS_FILE for stable/ussuri
  - Labels override
  - Update .gitreview for stable/ussuri
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.0.0
  - Drop py27 tests
  - Update hacking for Python3
  - Replace git.openstack.org URLs with opendev.org URLs
  - Allow cluster config for any cluster state
  - Update master for stable/train
  - Update links in README
  - Add nodegroup CRUD commands
  - Bugfix: Use fields option for cluster template list
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 2.15.0
  - Add nodegroup list/show commands
  - Support upgrade API
  - Fix coverage test
  - Update master for stable/stein
  - Support resize api
  - Add Python 3 Train unit tests
  - python3 fixes
  - Conditional hidden arg for backward compatibility
  - Add hidden property to cluster template
  - OpenDev Migration Patch
  - Display project_id for cluster show
  - Dropping the py35 testing
  - add python 3.7 unit test job
  - Change openstack-dev to openstack-discuss
  - Support health_status on client side
  - Blacklist bandit 1.6.0 and cap Sphinx on Python2
  - Support network, subnet and FIP when creating cluster
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 2.12.0
  - Add Python 3.6 classifier to setup.cfg
  - Fix py37 compatibility
  - Trivial: Update pypi url to new url
  - [k8s] Add embed certs to config
  - osc: Don't pass parameters with null value
  - Use oslo_serialization instead of the json module directly
  - switch documentation job to new PTI
  - Fix crash on Service catalog empty 403 response
  - add python 3.6 unit test job
  - Use template for lower-constraints
  - import zuul job settings from project-config
  - Keystone auth support
  - Add release notes for magnum client
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 2.10.0
  - Add deprecation warnings to magnum client commands
  - Follow the new PTI for document build
  - Now cluster-template-update works for "labels"
  - Switch to stestr
  - OSC command for ca-show, ca-sign, ca-roatate and stats-list
  - Replace six.iteritems() with dict.items() in python-magnumclient
  - Make cluster-config rbac compatible for kubebernetes
  - OSC command for magnum quota's
  - fix tox python3 overrides
  - add lower-constraints job
  - Fix entrypoints for quotas
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 2.8.0 (bsc#1078607)
  - Add oslo.log as requirement
  - Replace six.iteritems() with .items()
  - OSC: Add --labels to coe cluster create
  - OSC: Add --flavor to coe cluster create
  - OSC: Add magnum service-list command
  - Add missing master_flavor_id in cluster attributes
  - Make cluster config --force a boolean
  - Add disable floating ip parameter
  - OSC: Remove unused files
  - inline comment typo fix
  - Now `name` is a positional argument in cluster creation
  - Add --labels for cluster-create
  - OSC: Add --master-flavor to coe cluster create
  - Cleanup test-requirements
  - Set --labels default to None on cluster create
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 2.7.0
  - Make cluster name positional in ca-show
  - Add --docker-volume-size for cluster-create
  - Change assertTrue(isinstance()) by optimal assert
  - Remove log translations
  - Make --profile load from environment variables
  - remove slash from kubernetes cluster context name
  - Don't set a default for docker_volume_size
  - Update the documentation link for doc migration
  - OSC: Add cluster config command
  - OSC 2/4 Add Cluster Create and List
  - switch to openstackdocstheme
  - OSC 3/4 Add remaining CT commands
  - OSC 1/4 Add CT create and UT framework
  - Remove docker-volume-size from cluster-list
  - Updated from global requirements
  - OSC 4/4 Add remaining cluster commands
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 2.6.0
  - Add magnum client support for resource quotas
  - Correct mistake from OSprofiler help
  - Update .gitignore to ignore .eggs
  - The python 3.4 support is removed
  - Fix wrong path reference.
  - Magnum client suport insecure_registry
  - Simplify magnumclient.shell.OpenStackMagnumShell.main()
  - Fix UT for duplicate name args test case
  - Update test requirement
  - Add ca-rotate command to magnumclient
  - Replace assertRaisesRegexp with assertRaisesRegex
  - Compare test coverage with the master branch
  - Move cover.sh to the tools directory
  - Make --cluster option required for ca-rotate
  - Print exception details on update failure
  - Allow name as positional argument
  - Remove support for keyapir UUID
  - Use assertIsNone(...) instead of assertEqual(None, ...).
  - Increase Test coverage
  - Updated from global requirements
  - Add the support for 'detail' flag
* Fri Jul  7 2017 cloud-devel@suse.de
- update to version 2.5.0
  - Add the OSC 'cluster template list' command
  - Add osc-lib to requirements.txt
  - Increase UT Coverage
  - Updated from global requirements
  - Add usage docs for magnum client
* Fri Jun 23 2017 tbechtold@suse.com
- update requirements
* Tue Feb 21 2017 cloud-devel@suse.de
- update to version 2.4.0:
  - Fix passing TLS_VERIFIED in clusters/bays_shell
  - Enable DeprecationWarning in test environments
  - Add --keypair-id for cluster-create
  - Remove invalid check for 'manifest' path
  - Show team and repo badges on README
  - cluster-config return absolute path
  - Adding stats-list command to magnum client
  - Rollback cluster/bay on update failure
  - delete python bytecode including pyo before every test run
  - Increase UT Coverage
  - Cluster creation command returns complete cluster uuid
  - Implement Parameter Deprecation
  - Fix: swarm cluster-config, bay-config with tls_disabled
  - Use testr coverage feature
  - Add missing options for HTTPClient if auth_token given.
  - Fix the generated k8s config file
  - Fix: some typos in unit test
  - Magnum cluster-config/bay-config compatible with py3
  - Add magnum.bash_completion
  - Replace assertTrue(a in b) with assertIn(a, b)
  - Add OSC command for cluster_templates list
  - Increase UT coverage
  - Remove Not used Classes/Methods from apiclient.base
  - Mark help messages for Translation
  - Add .venv directory to .gitignore
  - Fix a keyward arguement error on bay-config
  - Sync tools/tox_install.sh
  - Use assert_called_*/assert_not_called to verify mock calls
  - Remove white space between print and ()
  - Remove H903 error in sources.
  - Integrate OSprofiler in Magnum Client
  - Added link for modindex
  - Renames *-id parameters
  - Pass 'api_version' to create HTTPClient
  - Add __ne__ built-in function
  - Add a deprecation message to the bay* commands' help text
  - Updated from global requirements
  - Allow cluster-config on cluster status 'ROLLBACK_COMPLETE'
* Thu Nov  3 2016 tbechtold@suse.com
  update to version 2.3.1
  * Update .gitreview for stable/newton
  * Add missing options for HTTPClient if auth_token given.
- Switch to stable/newton in _service
* Tue Sep  6 2016 tbechtold@suse.com
  update to version 2.3.0
  * Base OSC plugin support
  * Use os-client-config in shell
  * Use upper constraints for all jobs in tox.ini
  * Magnum client to support sync and async bay opts
  * Remove discover from test-requirements
  * Prints  '-' instead of 'None' when data is None
  * Updates certificate CLI to use cluster
  * Increase unit test coverage for module baymodels
  * Adds 'cluster' and 'cluster template'
  * Add Python 3.5 classifier and venv
  * Add shell command bay-config
  * Cleanup coverage configuration
  * bay-config return absolute path
  * Update the magnum client to send the latest version.
  * Enabled magnum client to display detailed information
  * Fix to use HttpClient if token is given
  * Fixes bay_uuid parameter issue in functional tests
  * Display baymodel info with bay-show command
  * Add microversioning support for httpclient
  * Add floating_ip_enabled attributes to baymodel
  * Append value using comma if key exists in label
  * Updated from global requirements
* Tue Aug 30 2016 tbechtold@suse.com
- update to 2.2.0:
  * Updated from global requirements
  * Bay_create_timeout should be set to 60 default
  * Pass a flag to disable LB in baymodels
  * Log appropriate error while exception
  * Add fixed_subnet attributes to baymodel
  * Support OS_PROJECT_* env variables
  * Completely remove openstack common modules
  * Add docker-storage-driver argument to baymodel
  * Tox test should respect upper-constraints
  * Switch to a new service type "container-infra"
  * Add mesos_slave_executor_environment_variables validate in CLI
  * Add some fields back to bay_list
  * Add '--fields' to show more columns for bay-list
  * Update the home-page with developer documentation
  * Correcting help messages of baymodel
  * Add python3 to python classifiers
  * Add '--fields' to show more columns for baymodel-list
  * Corrected spacing mistake in baymodels_shell.py
  * Fix the bug when some value in labels has comma, it will fail
  * Remove k8s pods, rcs, svc and container API calls
  * Add endpoint_override parameter to python-magnumclient
  * Revert "Parameter format change for ca-show and ca-sign"
  * Parameter format change for ca-show and ca-sign
  * Fix the container-list with --limit 'a negative number'
  * Remove the update function of container
  * Add missing user message
  * Add marker/limit/sort-key/sort-dir features for bay-list
  * Add marker/limit/sort-key/sort-dir features for container-list
  * Allow semicolons in list of labels
  * Add unit tests for MServiceManager.list() method
  * Add unit tests for ContainerManager.list() method
  * Add unit tests for BayModelManager.list() method
  * Add unit tests for BayManager.list() method
  * Adapt http response error message parsing
- update _service and switch to upstream spec template
* Wed Apr 13 2016 tbechtold@suse.com
- Initial packaging (version 2.0.0)
